@@ -77,7 +77,7 @@ class BaseTestEnd2End(AEATestCaseMany, UseFlaskTendermintNode, UseLocalIpfs):
     capture_log = True
     # generic service configurations
     ROUND_TIMEOUT_SECONDS = 10.0
-    OBSERVATION_INTERVAL = 10
+    RESET_PAUSE_DURATION = 10
     KEEPER_TIMEOUT = 30.0
     # generic node healthcheck configuration
     HEALTH_CHECK_MAX_RETRIES = 20
@@ -172,10 +172,8 @@ class BaseTestEnd2End(AEATestCaseMany, UseFlaskTendermintNode, UseLocalIpfs):
                 f"vendor.{skill.author}.skills.{skill.name}.models.params.args.setup.all_participants",
                 json.dumps(
                     [
-                        [
-                            Web3.toChecksumAddress(pairs[0])
-                            for pairs in key_pairs[:nb_agents]
-                        ]
+                        Web3.toChecksumAddress(pairs[0])
+                        for pairs in key_pairs[:nb_agents]
                     ]
                 ),
                 "list",
@@ -208,8 +206,8 @@ class BaseTestEnd2End(AEATestCaseMany, UseFlaskTendermintNode, UseLocalIpfs):
             type_="str",
         )
         self.set_config(
-            f"vendor.{skill.author}.skills.{skill.name}.models.params.args.observation_interval",
-            self.OBSERVATION_INTERVAL,
+            f"vendor.{skill.author}.skills.{skill.name}.models.params.args.reset_pause_duration",
+            self.RESET_PAUSE_DURATION,
             type_="int",
         )
         self.set_config(
