@@ -40,6 +40,7 @@ from aea_test_autonomy.fixture_helpers import (
     GanacheBaseTest,
     HardHatAMMBaseTest,
     HardHatGnosisBaseTest,
+    RegistriesBaseTest,
 )
 from aea_test_autonomy.helpers.contracts import get_register_contract
 
@@ -53,6 +54,7 @@ class BaseContractTest(ABC):
     identifier: str = EthereumCrypto.identifier
     deployer_crypto: Crypto
     contract_address: Optional[str] = None
+    deploy_contract: bool = True
 
     @classmethod
     def _setup_class(cls, **kwargs: Any) -> None:
@@ -83,8 +85,10 @@ class BaseContractTest(ABC):
             cls.deployer_crypto = crypto_registry.make(
                 cls.identifier, private_key_path=output_file
             )
-        cls.deploy(**cls.deployment_kwargs())
-        assert cls.contract_address is not None, "Contract not deployed."  # nosec
+
+        if cls.deploy_contract:
+            cls.deploy(**cls.deployment_kwargs())
+            assert cls.contract_address is not None, "Contract not deployed."  # nosec
 
     @classmethod
     def deploy(cls, **kwargs: Any) -> None:
@@ -131,6 +135,12 @@ class BaseHardhatAMMContractTest(BaseContractTest, HardHatAMMBaseTest):
     """Base test case for testing AMM contracts on Hardhat."""
 
 
+class BaseRegistriesContractsTest(BaseContractTest, RegistriesBaseTest):
+    """Base test case for the registries contract."""
+
+    deploy_contract: bool = False
+
+
 class BaseContractWithDependencyTest(BaseContractTest):
     """Base test contract with contract dependencies"""
 
